@@ -59,6 +59,7 @@ NULL
 #' @export
 #' @rdname geom_textsf
 #' @inheritParams ggplot2::geom_point
+#' @inheritParams static_text_params
 #' @inheritDotParams geom_textpath -arrow -lineend -linejoin -linemitre
 #' @md
 geom_textsf <- function(
@@ -66,10 +67,11 @@ geom_textsf <- function(
   data        = NULL,
   stat        = "sf",
   position    = "identity",
+  ...,
+  remove_long = TRUE,
   na.rm       = FALSE,
   show.legend = NA,
-  inherit.aes = TRUE,
-  ...
+  inherit.aes = TRUE
 ) {
 
   rlang::check_installed("sf", "for `geom_textsf()`")
@@ -82,7 +84,11 @@ geom_textsf <- function(
       position    = position,
       show.legend = show.legend,
       inherit.aes = inherit.aes,
-      params      = list(na.rm = na.rm, ...)
+      params      = set_params(
+        na.rm = na.rm,
+        remove_long = remove_long,
+        ...
+      )
     ),
     coord_sf(default = TRUE)
   )
@@ -92,16 +98,18 @@ geom_textsf <- function(
 #' @export
 #' @rdname geom_textsf
 #' @inheritParams ggplot2::geom_point
+#' @inheritParams static_text_params
 #' @inheritDotParams geom_labelpath -arrow -lineend -linejoin -linemitre
 geom_labelsf <- function(
   mapping     = aes(),
   data        = NULL,
   stat        = "sf",
   position    = "identity",
+  ...,
+  remove_long = TRUE,
   na.rm       = FALSE,
   show.legend = NA,
-  inherit.aes = TRUE,
-  ...
+  inherit.aes = TRUE
 ) {
 
   rlang::check_installed("sf", "for `geom_labelsf()`")
@@ -114,7 +122,11 @@ geom_labelsf <- function(
       position    = position,
       show.legend = show.legend,
       inherit.aes = inherit.aes,
-      params = list(na.rm = na.rm, ...)
+      params      = set_params(
+        na.rm = na.rm,
+        remove_long = remove_long,
+        ...
+      )
     ),
     coord_sf(default = TRUE)
   )
@@ -141,7 +153,7 @@ GeomTextsf <- ggproto("GeomTextSf", GeomSf,
     family     = "",
     fontface   = 1,
     lineheight = 1.2,
-    alpha      = 1,
+    alpha      = NA,
     linewidth  = 0.5,
     spacing    = 0,
     linecolour = "gray30",
@@ -149,7 +161,7 @@ GeomTextsf <- ggproto("GeomTextSf", GeomSf,
 
   draw_panel = function(data, panel_params, coord, legend = NULL,
                         lineend = "butt", linejoin = "round", linemitre = 10,
-                        text_smoothing = 0,
+                        text_params = static_text_params("text"),
                         arrow = NULL, na.rm = TRUE) {
     if (!inherits(coord, "CoordSf")) {
       abort("geom_sf() must be used with coord_sf()")
@@ -157,7 +169,7 @@ GeomTextsf <- ggproto("GeomTextSf", GeomSf,
 
     data <- coord$transform(data, panel_params)
     sf_textgrob(data, lineend = lineend, linejoin = linejoin,
-                   linemitre = linemitre, text_smoothing = text_smoothing,
+                   linemitre = linemitre, text_params = text_params,
                    arrow = arrow, na.rm = na.rm)
   }
 )
@@ -173,7 +185,7 @@ GeomLabelsf <- ggproto("GeomLabelSf", GeomSf,
 
   default_aes = aes(
     colour       = "black",
-    alpha        = 1,
+    alpha        = NA,
     size         = 3.88,
     hjust        = 0.5,
     vjust        = 0.5,
@@ -194,14 +206,15 @@ GeomLabelsf <- ggproto("GeomLabelSf", GeomSf,
 
   draw_panel = function(data, panel_params, coord, legend = NULL,
                         lineend = "butt", linejoin = "round", linemitre = 10,
-                        arrow = NULL, text_smoothing = 0, na.rm = TRUE) {
+                        arrow = NULL, text_params = static_text_params("labels"),
+                        na.rm = TRUE) {
     if (!inherits(coord, "CoordSf")) {
       abort("geom_sf() must be used with coord_sf()")
     }
 
     data <- coord$transform(data, panel_params)
     sf_textgrob(data, lineend = lineend, linejoin = linejoin,
-                linemitre = linemitre, text_smoothing = text_smoothing,
+                linemitre = linemitre, text_params = text_params,
                 arrow = arrow, na.rm = na.rm, as_textbox = TRUE)
   }
 )
