@@ -105,9 +105,9 @@ st_as_grob.sfc_labelled <- function(
       gp <- gp[!is_e]
       x <- x[!is_e]
   }
+  params         <- textpath_vars$text_params
   hjust          <- textpath_vars$hjust %||% 0.5
-  vjust          <- textpath_vars$vjust %||% 0.5
-  text_smoothing <- textpath_vars$text_smoothing %||% 0
+  vjust          <- params$offset %||% textpath_vars$vjust %||% 0.5
 
   if (length(x)) {
       x        <- unclass(x)
@@ -122,12 +122,18 @@ st_as_grob.sfc_labelled <- function(
                    arrow          = arrow,
                    hjust          = hjust,
                    vjust          = vjust,
+                   halign         = params$halign %||% "left",
+                   gap            = params$gap %||% NA,
                    default.units  = default.units,
                    name           = name,
                    gp_path        = gp,
                    gp_text        = textpath_vars$gp_text,
-                   text_smoothing = text_smoothing,
-                   remove_long    = TRUE,
+                   straight       = params$straight %||% FALSE,
+                   upright        = params$upright %||% TRUE,
+                   text_smoothing = params$text_smoothing %||% 0,
+                   padding        = params$padding %||% unit(0.05, "inch"),
+                   rich           = params$rich %||% FALSE,
+                   remove_long    = params$remove_long %||% TRUE,
                    vp             = vp
                    )
   } else {
@@ -164,9 +170,9 @@ st_as_grob.sfc_textbox <- function(
       gp <- gp[!is_e]
       x  <- x[!is_e]
   }
+  params         <- textpath_vars$text_params
   hjust          <- textpath_vars$hjust %||% 0.5
-  vjust          <- textpath_vars$vjust %||% 0.5
-  text_smoothing <- textpath_vars$text_smoothing %||% 0
+  vjust          <- params$offset %||% textpath_vars$vjust %||% 0.5
 
   if (length(x)) {
       x        <- unclass(x)
@@ -181,13 +187,19 @@ st_as_grob.sfc_textbox <- function(
                    arrow          = arrow,
                    hjust          = hjust,
                    vjust          = vjust,
+                   halign         = params$halign %||% "left",
+                   gap            = params$gap %||% NA,
                    default.units  = default.units,
                    name           = name,
                    gp_path        = gp,
                    gp_text        = textpath_vars$gp_text,
                    gp_box         = textpath_vars$gp_box,
-                   text_smoothing = text_smoothing,
-                   remove_long    = TRUE,
+                   straight       = params$straight %||% FALSE,
+                   upright        = params$upright %||% TRUE,
+                   text_smoothing = params$text_smoothing %||% 0,
+                   padding        = params$padding %||% unit(0.05, "inch"),
+                   rich           = params$rich %||% FALSE,
+                   remove_long    = params$remove_long %||% TRUE,
                    vp             = vp,
                    as_label       = TRUE
                    )
@@ -208,7 +220,7 @@ sf_textgrob <- function(
   arrow          = NULL,
   na.rm          = TRUE,
   as_textbox     = FALSE,
-  text_smoothing = 0
+  text_params    = static_text_params("text")
 ) {
 
   # Match labels to data
@@ -279,11 +291,10 @@ sf_textgrob <- function(
                   linejoin  = linejoin,
                   linemitre = linemitre)
 
-  gp_text <- gpar(col           = textcol,
+  gp_text <- gpar(col           = alpha(textcol, alpha),
                   fontsize      = fontsize,
                   fontfamily    = family,
-                  fontface      = fontface,
-                  alpha         = alpha)
+                  fontface      = fontface)
 
   gp_box  <- gpar(col       = boxcolour,
                   lty       = boxlinetype,
@@ -291,9 +302,7 @@ sf_textgrob <- function(
                   fill      = boxfill)
 
   # Allow extra textpath / labelpath parameters to be passed to st_as_grob
-  tp_vars <- list(hjust          = x$hjust %||% 0.5,
-                  vjust          = x$vjust %||% 0.5,
-                  text_smoothing = text_smoothing %||% 0,
+  tp_vars <- list(text_params    = text_params,
                   gp_text        = gp_text,
                   gp_box         = gp_box)
   # Build grobs
@@ -302,6 +311,8 @@ sf_textgrob <- function(
   for (i in seq_along(x$geometry)) {
     g   <- label_sf(x$geometry[i], labels[i], as_textbox = as_textbox)
     tp_i <- tp_vars
+    tp_i$hjust <- x$hjust[i] %||% 0.5
+    tp_i$vjust <- x$vjust[i] %||% 0.5
     tp_i$gp_text <- tp_i$gp_text[i]
     tp_i$gp_box  <- tp_i$gp_box[i]
     out <- addGrob(out,
