@@ -244,30 +244,17 @@ find_missing <- function(x, layer) {
 
 # Label utilities --------------------------------------------------------------
 
-# S3 generic to ensure label vector matches to given object
+# Ensure label vector matches to given object
 
-match_labels <- function(x, ...) {
+match_labels <- function(x, labels) {
 
-  UseMethod("match_labels")
-}
-
-
-#S3 method to ensure labels are same length as data frame
-
-match_labels.data.frame <- function(x, labels) {
-
-  if (length(labels) == 1) labels <- rep(labels, nrow(x))
-  if (nrow(x) != length(labels)) {
-    stop("Could not match labels to object ", deparse(substitute(x)))
+  if(is.data.frame(x)) {
+    if (length(labels) == 1) labels <- rep(labels, nrow(x))
+    if (nrow(x) != length(labels)) {
+      stop("Could not match labels to object ", deparse(substitute(x)))
+    }
+    return(labels)
   }
-  labels
-}
-
-
-# match labels to vector or list
-
-match_labels.default <- function(x, labels) {
-
   if (length(labels) == 1) labels <- rep(labels, length(x))
   if (length(x) != length(labels)) {
     stop("Could not match labels to object ", deparse(substitute(x)))
@@ -275,7 +262,6 @@ match_labels.default <- function(x, labels) {
   labels
 }
 
-
 # Similar to ggplot's rename function
 
 rename <- function(x, replace) {
@@ -336,13 +322,19 @@ make_label <- function(x) {
 
 # Allows information about co-ordinate system to be passed to grob
 
-get_polar_params <- function(coord) {
+get_polar_params <- function(coord, params) {
 
   if (inherits(coord, "CoordPolar")) {
-      list(x = 0.5, y = 0.5, theta = coord$theta)
-    } else  {
-      NULL
-    }
+    list(x = 0.5, y = 0.5, theta = coord$theta)
+  } else if (inherits(coord, "CoordRadial")) {
+    list(
+      x = rescale(0.5, from = params$bbox$x),
+      y = rescale(0.5, from = params$bbox$y),
+      theta = coord$theta
+    )
+  } else {
+    NULL
+  }
 }
 
 
